/*
 *  swiapi.h
 *  swimac
 *
 *  Created by Jerry Pickering on 3/27/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIAPI_H__
#define __SWIAPI_H__

#ifdef __cplusplus
extern "C"	{
#endif

//////////////////////////////////////////////////////////////////////////////////
//                                                                              //
//--------------------------SWI Common API functions----------------------------//
//                                                                              //
//  All API functions return SWI_RCODE enum type value. For particular error    //
//  code see SwiRcodes.h.                                                       //
//  For details about parameter types, enumeration values and structures        //
//  see SwiStructs.h                                                            //
//                                                                              //
//////////////////////////////////////////////////////////////////////////////////


//////////////////API management group of functions///////////////////  


//////////////////////////////////////////////////////////////////////////////////
//
//	Name:	SwiApiStartup - to open the API
//
//	Purpose:	This function is used to open the API.
//
//	Parameters:
//
//
//	Return:	SWI_RCODE_OK
//			SWI_RCODE_FAILED
//			SWI_RCODE_SYSTEM_ERROR
//			SWI_RCODE_REQUEST_TIMEOUT
//			See SWI_RCODE for other error return codes
//
//	Notes:	SwiApiOpenEx is obsolete and replaced with SwiApiStartup.  Similar to
//			SwiApiOpenEx, SwiApiStartup must be called before any other API calls
//			can be made.  However, unlike SwiApiOpenEx, calling SwiApiStartup does
//			not establish a communication link with the  air server.  SwiApiStartup
//			merely initializes the API sub-system and allows for device detection.   
//
//			SwiApiStartup need only be called once for the lifetime of the application.
//			This is true even across device removals and suspend/resume cycles.
//			However, if SwiApiStartup fails or if SWI_NOTIFY_MUX_Shutdown is received,
//			SwiApiShutdown must be called before attempting another SwiApiStartup call.   
//
//			After a successful call to SwiApiStartup, SwiGetAvailAirServers may then
//			be called to obtain a full list of available air servers on the system.
//			Finally, SwiSelectAirServer and SwiRegisterCallback must be called to
//			select an appropriate air server and to register a callback function
//			before proceeding with control and status API calls.//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiStartup( /*SWI_STRUCT_ApiStartup *startupParams */);

//////////////////////////////////////////////////////////////////////////////////
//
//	Name:	SwiApiShutdown - to close the API
//
//	Purpose:	This function is used to close the API.
//
//	Parameters:
//
//	Return:	SWI_RCODE_OK
//			SWI_RCODE_FAILED
//			SWI_RCODE_SYSTEM_ERROR
//			SWI_RCODE_REQUEST_TIMEOUT
//			See SWI_RCODE for other error return codes
//
//	Notes:	SwiApiClose is obsolete and replaced with SwiApiShutdown.
//			SwiApiShutdown must be called to terminate the usage of the API.  This
//			command tears down any communication links established with the air
//			server and cleans up allocated resources. 
// 
//			Unlike SwiApiClose, applications do not have to call SwiApiShutdown
//			whenever a device removal is detected.  The API sub-system is valid
//			from the successful call of SwiApiStartup until SwiApiShutdown is
//			called or until SWI_NOTIFY_MUX_Shutdown is received. 
// 
//			Once SwiApiShutdown is called, all API function calls are no longer
//			allowed.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiShutdown();

//////////////////////////////////////////////////////////////////////////////////
//
//	Name:	SwiGetAvailAirServers
//
//	Purpose:	This function is used to retrieve a list of available air servers
//				on the system.
//
//	Parameters:
//
//	Return:	SWI_RCODE_OK
//			SWI_RCODE_FAILED
//			SWI_RCODE_SYSTEM_ERROR
//			SWI_RCODE_REQUEST_TIMEOUT
//			See SWI_RCODE for other error return codes
//
//	Notes:	This function is used to retrieve a list of available air servers on
//			the system.  Air servers returned in the list can then be used by
//			SwiSelectAirServer to establish communication with the air server.
//			However, if the initial call to SwiGetAvailAirServers returns no
//			available air servers, it is best to monitor for
//			SWI_NOTIFY_AirServerChange for the availability of new air servers
//			instead of polling with SwiGetAvailAirServers.  Note that a callback
//			function must be registered with SwiRegisterCallback before any
//			notifications can be received.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetAvailAirServers();

//////////////////////////////////////////////////////////////////////////////////
//
//	Name:	SwiSelectAirServer
//
//	Purpose:	This function is used to configure the API to be used with a
//				specified air server.
//
//	Parameters:
//
//	Return:	SWI_RCODE_OK
//			SWI_RCODE_FAILED
//			SWI_RCODE_SYSTEM_ERROR
//			SWI_RCODE_REQUEST_TIMEOUT
//			See SWI_RCODE for other error return codes
//
//	Notes:	This function is used to configure the API to be used with a specified
//			air server.  The specified air server should be one retrieved with
//			SwiGetAvailAirServers or from a SWI_NOTIFY_AirServerChange
//			notification.  SwiRegisterCallback must always be called immediately
//			after SwiSelectAirServer to ensure that the newly configured API has
//			the required callback function pointer to receive notifications.   
//
//			Only one air server can be selected at any given time.  Calling
//			SwiSelectAirServer when an air server has already been selected will
//			cause the API to reconfigure itself for the new air server
//			(SwiRegisterCallback must be called again).
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSelectAirServer();

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiApiOpen - to open the API
//
// Purpose:	This function is used to open the API for a particular device.
//			The family of Aircards and SB modules are valid devices.
//
// Parameters:
//
//			eDevice[IN]:	Enumerated name of the modem device you are 
//							connecting to. 
//							This tells the API what services will be supported.
//
//			OpenParams[IN]:	parameters to open the API in different modes
//
//			DevicePath[IN]: name of the device to open
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_FAILED - The Modem API layer was not initialized successfully.
//							The modem driver may not be available, or eDevice is 
//							not supported.
//			SWI_RCODE_SYSTEM_ERROR - This may be due to limited system resources 
//							when the API requested memory from the OS.
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	SwiRegisterCallback must be called immedately after SwiApiOpen (1xRtt
//          applications must also call SwiIsModemReady).
//
//          If an error is returned or to re-initialize the API, SwiApiClose must 
//			be called before calling this function again.
//
//			If device type is MUX (EM5625/MC5720), pass SWI_U8* as SWI_STRUCT_Port_Info 
//			to get more information for MUX ports and device. Pass NULL if not needed	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiOpen(SWI_TYPE_Device eDevice, SWI_U8 *OpenParams, char *DevicePath);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiApiOpenWithSeize - to open the API
//
// Purpose:	This function is used to open the API for a particular device.
//			The family of Aircards and SB modules are valid devices.
//
//			It differs from SwiApiOpen() in that it will open a direct connection
//			to the USB endpoints if the driver is not available or if the driver
//			is in use by another process.
//
//			Once this call has been made, the driver no longer has control over
//			the device, even after the connection is closed (with SwiApiClose()).
//			In order to restore the connection properly, SwiResetModem() should be
//			called just prior to SwiApiClose().
//
//
// Parameters:
//
//			eDevice[IN]:	Enumerated name of the modem device you are 
//							connecting to. 
//							This tells the API what services will be supported.
//
//			OpenParams[IN]:	parameters to open the API in different modes
//
//			DevicePath[IN]: name of the device to open
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_FAILED - The Modem API layer was not initialized successfully.
//							The modem driver may not be available, or eDevice is 
//							not supported.
//			SWI_RCODE_SYSTEM_ERROR - This may be due to limited system resources 
//							when the API requested memory from the OS.
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	SwiRegisterCallback must be called immedately after SwiApiOpen (1xRtt
//          applications must also call SwiIsModemReady).
//
//          If an error is returned or to re-initialize the API, SwiApiClose must 
//			be called before calling this function again.
//
//			If device type is MUX (EM5625/MC5720), pass SWI_U8* as SWI_STRUCT_Port_Info 
//			to get more information for MUX ports and device. Pass NULL if not needed	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiOpenWithSeize(SWI_TYPE_Device eDevice, SWI_U8 *OpenParams, char *DevicePath);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiApiClose - to close the API
//
// Purpose:	This function is called to shut down the Modem API. It will close 
//			control and status access to the modem but will not impact data traffic 
//			use of the AirCard modem over NDIS, nor the SB555 data path on the 
//			primary COM port.
//
// Parameters:
//
//			None
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	After calling this function, the Modem API will no longer be available. 
//			You must re-initialize the API before any further API functions can be
//			called.  Closing the API will not impact the data path to the device. 
//			Any open session will continue. The API provides only the link for control 
//			and status functions.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiClose(void);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiApiClosePort - to close the port (only ... not the whole API)
//
// Purpose:	This function is called to close the port associated with this modem
//
// Parameters:
//
//			None
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	After calling this function, the port is no longer available. However,
//			other API calls are still available.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiApiClosePort(void);	
	
//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiRegisterCallback - to register a callback function
//
// Purpose:	This function registers the application's callback function to receive 
//			event notifications.		
//
// Parameters:
//
//			pCallback[OUT]:		callback function pointer
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_INVALID_PAR  - an invalid parameter was passed
//
// Notes:	The application calls this function once, to register a handler for all 
//			event notifications.
//
//			This function must be called immedately after starting the API.
//
//			After the call to this registration function, notifications for all 
//			event types (except SWI_NOTIFY_Reset) remain disabled by default.
//			Event notifications must be individually enabled using SwiNotify. They 
//			can be disabled using SwiStopNotify.  Following registration of a 
//			callback function, subsequent calls to this service will replace the
//			pointer to the original handler with any new setting, allowing the 
//			programmer to change callback handlers if needed.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiRegisterCallback(SWI_CALLBACK_EX pCallback);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiUnRegisterCallback - to unregister a callback function
//
// Purpose:	This function unregisters the application's callback function to receive 
//			event notifications.		
//
// Parameters:
//
//			None
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_INVALID_PAR  - an invalid parameter was passed
//
// Notes:	The application calls this function to unregister all 
//			event notifications.
//
//			This function can be called any time after registering a callback.
//
//			After the call all notifications, regardless will be disabled.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiUnregisterCallback(void);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiNotify - to enable a notification
//
// Purpose:	This function turns the notification ON for the specified event type.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request has been processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			eNotify[IN]:		notification to enable
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out.  It is
//				harmless to re-request notifications.
//			See SWI_RCODE for other error return codes
//
// Notes:	Calling this function enables event notifications to be routed to the 
//			callback function registered earlier using SwiRegisterCallback. If 
//			notifications are enabled when there is no registered callback function, 
//			the API will silently discard them as they arrive.
//
//			Modem resets disable notifications (but leave the callback function 
//			registered). You must explicitly re-enable notifications if a modem reset 
//			is detected.  Notifications generally occur only when the value changes. 
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiNotify(SWI_TYPE_Notify eNotify, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiStopNotify - to stop (disable) a notification
//
// Purpose:	This function turns the notification OFF for the specified event.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request has been processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			eNotify[IN]:		notification to disable. (Do not attempt to 
//								disable notifications for SWI_NOTIFY_Reset.)
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	After calling this function, the specified notifications will not be 
//			forwarded to the client's callback function.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiStopNotify(SWI_TYPE_Notify eNotify, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetSDKVersion - to retrieve the SDK version
//
// Purpose:	This function returns the SDK version string. 
//			
// Parameters:
//
//			sSDKVers[OUT]:		SDK version
//
//			sLength[IN]:		length of the version string
//
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_INVALID_PAR  - invalid parameter
//			See SWI_RCODE for other error return codes
//
// Notes:	The version string varies in length. 
//			The returned string is null terminated.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSDKVersion(SWI_U8 *sSDKVers, SWI_U32 sLength);




//////////////////////////////////////////////////////////////////////////////////
//
// Unit characteristics
//
// These functions report information about the
// specific modem (hardware and software).
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiIsModemReady - Verify if modem is ready for use
//
// Purpose:     This function reports whether the modem is in a state where
//              it is ready for normal operation.  This function should be
//              called after successfully calling SwiRegisterCallback,
//              and before any other API function call.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      SWI_RCODE_OK            The modem is ready for use
//              SWI_RCODE_FAILED        The modem is not ready for use.
//										Repeated calls to this function should be
//										attempted until it succeeds.
//										
//
// Notes:       This function should always be called after successfully calling
//              SwiRegisterCallback (which is always called after SwiApiOpen or 
//              SwiApiOpenEx), and before any other API function call.
//				
//              When the modem undergoes a power cycle (typically after inserting
//              the modem or resuming from a reset or host suspend), the modem may 
//              take some time to initialize.  During this period, the modem
//              may not respond to any API modem functions, in spite a successful 
//              call with SwiApiOpen(Ex).  This function is used to test for
//              this condition, and should be repeatedly called until it succeeds.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiIsModemReady(SWI_U32 timeout);



//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDriverVersion - Get driver version
//
// Purpose:     This function returns a string identifying the
//              version of the AirCard driver.
//
// Parameters:  szLength[IN]            The maximum size of the output
//                                      string (szDriverVersion).
//              timeout[IN]             Function timeout in milliseconds
//              szDriverVersion[OUT]    The destination in which the
//                                      driver's version string is returned.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDriverVersion(SWI_U8 *szDriverVersion, SWI_U32 szLength, SWI_U32 timeout);







//////////////////////////////////////////////////////////////////////////////////
//
// Service characteristics
//
// These functions provide information about the
// the modemís connection to the host, and the
// radio connection to the service provider.
//
//////////////////////////////////////////////////////////////////////////////////



//////////////////////////////////////////////////////////////////////////////////
//
// Statistics
//
// Functions to report various modem and call statistics.
//
//////////////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////////////
//
// Activation Query Functions
//
// The following family of functions report information
// about the current account profiles.
//
//////////////////////////////////////////////////////////////////////////////////





//////////////////////////////////////////////////////////////////////////////////
//
// Activation Setting Functions
//
// This family of functions are used to unlock, store,
// and save NAM account profile data.
//
//////////////////////////////////////////////////////////////////////////////////





//////////////////////////////////////////////////////////////////////////////////
//
// Connection management
//
// This group of functions are related to controlling
// the connection status of the modem. This
// includes originating, answering (terminating),
// and disconnecting calls, as well as using the flash
// feature.
//
//////////////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////////////
//
// EVDO functions
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetERIVer - Get the ERI File Version
//
// Purpose:     This function gets the ERI version stored in the modem.
//
// Parameters:  pszERIFilename[IN]      ERI Filename stored in modem.
//              pnERIVer[IN]            ERI File Version.
//              timeout[IN]             Function timeout in milliseconds
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetERIVer(SWI_U8 *szERIFilename, SWI_U16 *pnERIVer, SWI_U32 timeout);



//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetEVDOSCPSettings
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetEVDOSCPSettings(SWI_U8 *pbUsesSCP ,SWI_U16 *pwCustCfgActive, SWI_U32 *pdwProtMask, 
                                        SWI_U32 *pdwBCMCSMask, SWI_U32 *pdwAppMask, SWI_U32 timeout);



//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMEIDESN
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetMEIDESN(SWI_STRUCT_MeidEsn *pMeidEsn, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiRtnReset 
//
// Purpose: Perform a RTN or PRI reset on the device.  This will reset the device to factory state.
//
// Parameters:  nType[OUT]           Type of reset (PRI_RESET = 1,RTN_RESET = 2)
//              timeout[IN]          Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   Note that this action may take several moments.
//			Be sure to call SwiResetModem() after calling SwiRtnReset() to apply it.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiRtnReset(SWI_U8 nType, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiResetModem - Resets the modem
//
// Purpose:     This function resets the modem.  This is typically done after
//              modifying particular modem settings that require a reset for
//              the new settings to take effect.
//				Typical scenarios requiring a modem reset include:
//              - Modem activation
//              - Modifying system select setting (SwiPstSetSystemPref)
//				- Changing the current active NAM (SwiPstSetCurrentNam)
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       During the period in which the modem resets and re-initializes,
//				the modem will not respond to any API requests.  
//
//				For AirCards, a SWI_NOTIFY_Reset notification will be sent when
//				the modem completes the reset.  See SWI_NOTIFY_Reset for details.
//				For other devices, it is recommended that one close the API
//				and reattempt opening the API until it succeeds.
//
//				After the reset, any previously enabled notifications must be 
//				re-enabled, and any previous modem states and/or information 
//				may no longer be valid.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiResetModem(SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDrvIntInfo - Get MUX 27.010 driver information
//
// Purpose:     The purpose is to get either version or port information for 
//				MUX 27.010 supported devices.
//
// Parameters:  QueryInfo[OUT]	Structure to pass in query type and retrive information
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       See SwiStructsCm.h for information how to use the structures.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDrvIntInfo(SWI_DRV_INT_QUERY *QueryInfo);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiStrError - Return a string representing a SWI_RCODE
//
// Purpose:     Allow for human readable error message
//
// Parameters:  swiErr[IN]	The numeric error code
//
// Return:      A string representation of the error code.
//
// Note:		Returns a pointer to a static; care must be taken to copy the
//				string if it is to be used by the caller elsewhere.
//
//////////////////////////////////////////////////////////////////////////////////
const char *SwiStrError( SWI_RCODE swiErr );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiStrNotification - Return a string representing a SWI_NOTIFY type
//
// Purpose:     Allow for human readable notification names
//
// Parameters:  aNotification[IN]	The numeric notification code
//
// Return:      A string representation of the notificadtion code.
//
// Note:		Returns a pointer to a static; care must be taken to copy the
//				string if it is to be used by the caller elsewhere.
//
//////////////////////////////////////////////////////////////////////////////////
const char *SwiStrNotification( SWI_TYPE_Notify aNotification );

	const char *SwiLastFWError();

//**********************************************************************************
//	SwiGetSDKData
//		This call returns all the SDK data in one structure
//		the primary use is to check all the "GET" calls for
//		the SDK
//**********************************************************************************

typedef struct
{
	SWI_RCODE			_ret[4];
	
	SWI_U8					_sSDKVers[CHAR_64];						// SDK Version string
	SWI_U8					_szDriverVersion[CHAR_64];				// Driver Version string
	SWI_U32					_szLength;								// ERI FileName length
	SWI_U8					_szERIFilename[CHAR_64];				// ERI FileName string
	SWI_U16					_pnERIVer;								// ERI Version number?
	SWI_DRV_INT_QUERY	_QueryInfo;								// Internal Driver info..  MUX 27.010 driver information

} SDK_DATA;


SWI_RCODE SwiGetSDKData(SDK_DATA *data);


#ifdef __cplusplus
}
#endif

#endif // __SWIAPI_H__
